<!DOCTYPE html>
<!--[if lt IE 7]>      <html class="no-js lt-ie9 lt-ie8 lt-ie7"> <![endif]-->
<!--[if IE 7]>         <html class="no-js lt-ie9 lt-ie8"> <![endif]-->
<!--[if IE 8]>         <html class="no-js lt-ie9"> <![endif]-->
<!--[if gt IE 8]>      <html class="no-js"> <!--<![endif]-->
<html>
    <head>
        {% block head %}
        <!-- Required meta tags -->
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <link rel="shortcut icon" href="{{ url_for('static', filename='favicon.ico') }}">
        <title>{% block title %}Beautiful loading screen{% endblock %}</title>
        <meta name="description" content="">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <script defer data-domain="{{ domain_name|default('start.fling.wtf')}}" src="https://plausible.io/js/script.js"></script>
        {% block styles %}
        <link href="{{url_for('static', filename='start/styles.css')}}" rel="stylesheet">
            <!-- Bootstrap CSS -->
            {{ bootstrap.load_css() }}
        {% endblock %}
        {% endblock %}
    </head>
    <body>
        <div id="maincontent">
        <!--[if lt IE 7]>
            <p class="browsehappy">You are using an <strong>outdated</strong> browser. Please <a href="#">upgrade your browser</a> to improve your experience.</p>
        <![endif]-->
            {% block content %}

            {% endblock %}
        </div>
        {% block scripts %}
            <!-- Optional JavaScript -->
            {{ bootstrap.load_js() }}
            
        {% endblock %}
    </body>
</html>